#
# spec file for package pinta
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pinta
Version:        1.6
Release:        5.2
Summary:        Drawing/editing application on C#
License:        MIT
Group:          Productivity/Graphics/Bitmap Editors
Url:            http://pinta-project.com/
Source:         https://github.com/PintaProject/Pinta/releases/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  mono(Mono.Addins)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glib-sharp-2.0)
BuildRequires:  pkgconfig(gtk-sharp-2.0)
BuildRequires:  pkgconfig(mono) >= 2.8
BuildRequires:  pkgconfig(mono-cairo)
Recommends:     %{name}-lang = %{version}
BuildArch:      noarch

%description
Pinta is a free, open source drawing/editing application designed
after Paint.NET. Its goal is to provide users with a simple yet
powerful way to draw and manipulate images.


%lang_package

%prep
%setup -q
# update the project and solution files for mono4
find . -name "*.sln" -print -exec sed -i 's/Format Version 10.00/Format Version 11.00/g' {} \;
find . \( -name "*.csproj" -o -name "*.proj" \) -print -exec sed -i 's#ToolsVersion="3.5"#ToolsVersion="4.0"#g; s#<TargetFrameworkVersion>.*</TargetFrameworkVersion>##g; s#<PropertyGroup>#<PropertyGroup><TargetFrameworkVersion>v4.5</TargetFrameworkVersion>#g; s#Mono.Posix, Version.*"#Mono.Posix"#g' {} \;

%build
autoreconf -fi
%configure --libdir=%{_libexecdir}
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}

%check
make check

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc license-mit.txt readme.md
%{_bindir}/%{name}
%{_libexecdir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_datadir}/pixmaps/%{name}.xpm
%{_mandir}/man?/%{name}.?%{?ext_man}

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Thu Jun 11 2015 dimstar@opensuse.org
- Fix build with mono 4.0 (sed hacks borrowed from Fedora).
* Tue May 19 2015 mailaender@opensuse.org
- enable checks
* Wed Mar  4 2015 sor.alexei@meowr.ru
- Update to 1.6:
  * New Features / Improvements:
    + Redesigned shape tools (demo video):
  - The Line tool now supports drawing curves and arrows.
  - Shapes remain editable after being drawn.
  - All shape tools now support drawing dashed lines.
    + All selection tools now support the Union, Exclude, Xor, and
    Intersection modes.
    + New community add-in repository - add-ins can be installed
    through the Add-in Manager dialog (via the Add-ins menu).
    + Redesigned New Image dialog, which includes presets,
    orientation and background options, and a thumbnail preview
    of the image.
    + The toolbox and color palette now have a flexible layout and
    can expand horizontally, making them significantly more
    usable on small screens.
    + When launching Pinta from the command line, the standard
  - -version and --help options are now supported.
  * Bug Fixes:
    + Fix a number of issues with the text tool’s support for
    Unicode text.
    + Fix a number of issues with undoing selections.
    + Fix a number of untranslatable strings throughout Pinta, and
    the zoom toolbar’s percentages are now formatted using the
    current locale.
    + The text tool now supports the standard shortcuts for
    toggling bold (Ctrl+B), italic (Ctrl+I), and underline
    (Ctrl+U), and all of the text can be selected with Ctrl+A.
    + Fix a potential crash after undoing a text action.
    + Fix a crash when holding both the left and right mouse
    buttons with the Pencil tool.
    + Fix issues with zooming in very far on large images.
    + Fix a potential crash when exiting Pinta.
    + Fix issues with the toolbar’s state (hidden vs. visible) not
    being preserved after re-opening Pinta.
    + Fix several bugs where undo did not work correctly for the
    Freeform Shape tool.
    + Fix a bug where resizing a selection allowed the selection to
    grow beyond the edge of the canvas.
    + The selection handles are now larger and easier to click.
    + Fix bugs where using the Recolor tool after the Line/Curve
    tool resulted in odd behavior.
    + The error dialog now includes a link to the bug tracker.
    + Improve the error message when opening an unsupported file
    format.
    + Fix an issue where cancelling the saving of a jpg image made
    it appear that the image had actually been saved.
    + Auto-hiding now works correctly for the history and open
    images pads.
    + Auto Crop now works correctly if there is an active selection.
    + The progress dialog is now modal.
    + The Backspace and Delete keys are now usable when editing
    text fields in the toolbar.
    + Improve the readability of the text cursor against dark
    backgrounds.
- Spec cleanup.
- Add pinta-lang package.
* Mon May 26 2014 develop7@develop7.info
- update to v1.5
  * see https://github.com/PintaProject/Pinta/releases/tag/1.5
* Sat Apr 12 2014 mailaender@opensuse.org
- added %%post macros
* Thu Sep 27 2012 i@marguerite.su
- update to 1.4
  * http://pinta-project.com/Releases.Release%%201-4.ashx
* Wed Jun 13 2012 mailaender@opensuse.org
- Update to 1.3
  * http://pinta-project.com/Releases.1-3.ashx
* Wed Apr 18 2012 i@marguerite.su
- update to 1.1
  * http://pinta-project.com/Releases.1-1.ashx
* Thu Apr 28 2011 ajorgensen@novell.com
- Update to 1.0
  * http://pinta-project.com/Release-Notes-1-0.ashx
* Fri Jan 14 2011 malcolmlewis@opensuse.org
- Add missing Url tag
* Wed Jan 12 2011 malcolmlewis@opensuse.org
- Update to 0.6
  http://pinta-project.com/release/0.6
- Spec file cleanup
- Desktop patch dropped
* Fri Jul  9 2010 ajorgensen@novell.com
- Update to 0.4
  http://pinta-project.com/release/0.4
* Mon May 24 2010 ajorgensen@novell.com
- Update to 0.3
  http://pinta-project.com/release/0.3
* Mon Mar 15 2010 ajorgensen@novell.com
- Update to 0.2
  http://www.pinta-project.com/release/0.2
* Mon Mar  8 2010 ajorgensen@novell.com
- First version (0.1)
